function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var DrizzleContext = React.createContext(null);
function useDrizzle() {
  return React.useContext(DrizzleContext);
}

function capitalize(str) {
  return "" + str.charAt(0).toUpperCase() + str.substring(1);
}

function createUseMethod(drizzle, contractName, methodName) {
  return ["use" + capitalize(methodName), function () {
    var dataKey = React.useRef(null);
    var state = drizzle.store.getState();
    React.useEffect(function () {
      if (!dataKey.current) {
        dataKey.current = drizzle.contracts[contractName].methods[methodName].cacheCall();
      }
    });
    var data = state.contracts[contractName][methodName][dataKey.current];
    return data === null || data === void 0 ? void 0 : data.value;
  }];
}

function createUseContract(drizzle, contractName, methods) {
  var filteredMethodKeys = Object.keys(methods).filter(function (name) {
    return name.match(/^(?!0x)[\w\d]*$/);
  });
  var methodHooks = Object.fromEntries(filteredMethodKeys.map(function (methodName) {
    return createUseMethod(drizzle, contractName, methodName);
  }));
  return ["use" + contractName, function () {
    return methodHooks;
  }];
}

function DrizzleProvider(_ref) {
  var drizzle = _ref.drizzle,
      children = _ref.children;

  var _useState = React.useState(true),
      drizzleLoading = _useState[0],
      setDrizzleLoading = _useState[1];

  var _useState2 = React.useState({}),
      drizzleContext = _useState2[0],
      setDrizzleContext = _useState2[1];

  var state = drizzle.store.getState();
  React.useEffect(function () {
    return drizzle.store.subscribe(function () {
      var newState = drizzle.store.getState();
      var initialized = newState.drizzleStatus.initialized;

      if (!initialized) {
        return;
      }

      var contractNames = Object.keys(drizzle.contracts);
      var contractHooks = Object.fromEntries(contractNames.map(function (name) {
        return createUseContract(drizzle, name, drizzle.contracts[name].methods);
      }));
      setDrizzleContext(_extends({
        drizzle: drizzle,
        state: newState
      }, contractHooks));
      setDrizzleLoading(false);
    });
  }, [drizzleLoading, state]);
  return /*#__PURE__*/React__default.createElement(DrizzleContext.Provider, {
    value: _extends({
      loading: drizzleLoading
    }, drizzleContext)
  }, children);
}

exports.default = DrizzleProvider;
exports.useDrizzle = useDrizzle;
//# sourceMappingURL=index.js.map
