import React, { createContext, useContext, useRef, useEffect, useState } from 'react';

const DrizzleContext = createContext(null);
function useDrizzle() {
  return useContext(DrizzleContext);
}

function capitalize(str) {
  return `${str.charAt(0).toUpperCase()}${str.substring(1)}`;
}

function createUseMethod(drizzle, contractName, methodName) {
  return [`use${capitalize(methodName)}`, () => {
    const dataKey = useRef(null);
    const state = drizzle.store.getState();
    useEffect(() => {
      if (!dataKey.current) {
        dataKey.current = drizzle.contracts[contractName].methods[methodName].cacheCall();
      }
    });
    const data = state.contracts[contractName][methodName][dataKey.current];
    return data === null || data === void 0 ? void 0 : data.value;
  }];
}

function createUseContract(drizzle, contractName, methods) {
  const filteredMethodKeys = Object.keys(methods).filter(name => name.match(/^(?!0x)[\w\d]*$/));
  const methodHooks = Object.fromEntries(filteredMethodKeys.map(methodName => createUseMethod(drizzle, contractName, methodName)));
  return [`use${contractName}`, () => methodHooks];
}

function DrizzleProvider({
  drizzle,
  children
}) {
  const [drizzleLoading, setDrizzleLoading] = useState(true);
  const [drizzleContext, setDrizzleContext] = useState({});
  const state = drizzle.store.getState();
  useEffect(() => {
    return drizzle.store.subscribe(() => {
      const newState = drizzle.store.getState();
      const {
        drizzleStatus: {
          initialized
        }
      } = newState;

      if (!initialized) {
        return;
      }

      const contractNames = Object.keys(drizzle.contracts);
      const contractHooks = Object.fromEntries(contractNames.map(name => createUseContract(drizzle, name, drizzle.contracts[name].methods)));
      setDrizzleContext({
        drizzle,
        state: newState,
        ...contractHooks
      });
      setDrizzleLoading(false);
    });
  }, [drizzleLoading, state]);
  return /*#__PURE__*/React.createElement(DrizzleContext.Provider, {
    value: {
      loading: drizzleLoading,
      ...drizzleContext
    }
  }, children);
}

export default DrizzleProvider;
export { useDrizzle };
//# sourceMappingURL=index.modern.js.map
